@@ -22,7 +22,7 @@
 import os
 import shutil
 
-from base import utils, tui, os_utils, validation
+from base import utils, tui, os_utils, validation, password
 from base.g import *
 from base.codes import *
 from base.strings import *
@@ -91,6 +91,8 @@ class PluginHandle(object):
         processor = utils.getProcessor()
         if processor == 'power_machintosh':
             ARCH = 'ppc'
+        elif (processor == 'armv6l' or processor == 'armv7l' or processor == 'aarch64' or processor == 'aarch32'):
+            ARCH = 'arm%d' % BITNESS
         else:
             ARCH = 'x86_%d' % BITNESS
 
@@ -345,21 +347,21 @@ class PluginHandle(object):
         cwd = os.getcwd()
         os.chdir(self.__plugin_path)
 
+        exec_str = sys.executable
         if mode == GUI_MODE:
-            cmd = "sh %s --keep --nox11 -- -u" % plugin_file
+            cmd = "sh %s --keep --nox11 -- -u %s" % (plugin_file, exec_str)
+            status = os_utils.execute(cmd)
         else:
-            cmd = "sh %s --keep --nox11 -- -i" % plugin_file
-
-        if os_utils.execute(cmd) == 0:
+            cmd = "sh %s --keep --nox11 -- -i %s" % (plugin_file, exec_str)
+            status = os_utils.execute(cmd)
+        if status == 0:
             result = True
         else:
             log.error("Python gobject/dbus may be not installed")
             result = False
 
-        try:
-            shutil.rmtree('./plugin_tmp')
-        except OSError:
-            log.warn("Failed to remove the temporary files")
+
+        utils.remove('./plugin_tmp')
 
         os.chdir(cwd)
         return result
