@@ -184,7 +184,7 @@ def start(language, auto=True, test_depends=False,
         if not ok:
             sys.exit(0)
 
-        if PY3 and core.distro_name.lower() == 'fedora':
+        if PY3 and core.distro_name.lower() == 'fedora' and int(core.distro_version) < 22:
              global Fedora_Py3               # Workaround due to incomplete Python3 support in Linux distros.
              Fedora_Py3 = True
 
@@ -372,15 +372,37 @@ def start(language, auto=True, test_depends=False,
         #
         # REQUIRED DEPENDENCIES INSTALL
         #
-        package_mgr_cmd = core.get_distro_data('package_mgr_cmd')
+        package_mgr_cmd = core.get_distro_ver_data('package_mgr_cmd')
         depends_to_install = []
         depends_to_install_using_pip = []
+
+        if num_req_missing or num_opt_missing:
+            tui.title("MISSING DEPENDENCIES")
+            log.info("Following dependencies are not installed. HPLIP will not work if all REQUIRED dependencies are not installed and some of the HPLIP features will not work if OPTIONAL dependencies are not installed.")
+
+            log.info("%-20s %-20s %-20s"%( "Package-Name", "Component", "Required/Optional"))
+            for d in core.dependencies:
+                if (not core.have_dependencies[d]):
+                    if core.dependencies[d][0]:
+                        deptype = "REQUIRED"
+                    else:
+                        deptype = "OPTIONAL"
+                        
+                    log.info("%-20s %-20s %-20s" %(d, core.dependencies[d][1][0], deptype))
+
+            ok, ans = tui.enter_yes_no("Do you want to install these missing dependencies")
+            if not ok:
+                sys.exit(0)  
+
+            if not ans and num_req_missing:
+                log.error("Installation can not continue because all REQUIRED dependencies are not installed.")                
+                sys.exit(0)  
+
+
         if num_req_missing:
             tui.title("INSTALL MISSING REQUIRED DEPENDENCIES")
-
-            log.warn("There are %d missing REQUIRED dependencies." % num_req_missing)
             log.notice("Installation of dependencies requires an active internet connection.")
-
+            
             for depend, desc, option in core.missing_required_dependencies():
                 log.warning("Missing REQUIRED dependency: %s (%s)" % (depend, desc))
                 if Fedora_Py3:              # Workaround due to incomplete Python3 support in Linux distros.
@@ -431,8 +453,6 @@ def start(language, auto=True, test_depends=False,
         #
         if num_opt_missing:
             tui.title("INSTALL MISSING OPTIONAL DEPENDENCIES")
-            log.warn("There are %d missing OPTIONAL dependencies." % num_opt_missing)
-
             log.notice("Installation of dependencies requires an active internet connection.")
 
             for depend, desc, required_for_opt, opt in core.missing_optional_dependencies():
@@ -544,7 +564,7 @@ def start(language, auto=True, test_depends=False,
 
             packages = []
             commands_to_run = []
-            package_mgr_cmd = core.get_distro_data('package_mgr_cmd')
+            package_mgr_cmd = core.get_distro_ver_data('package_mgr_cmd')
 
             # HACK!
             individual_pkgs = True
@@ -626,7 +646,7 @@ def start(language, auto=True, test_depends=False,
 
                                 log.error("Package install command failed with error code %d" % status)
                                 if PY3:
-                                    log.notice("Some installation may not get installed on python3 due to distro incompatibilites")
+                                    log.notice("Some packages may not get installed on python3 due to distro incompatibilites")
                                     log.info("")
                                     log.notice("Please check for more information at http://hplipopensource.com/node/369")
                                 ok, ans = tui.enter_yes_no("Would you like to retry installing the missing package(s)")
@@ -871,15 +891,13 @@ def start(language, auto=True, test_depends=False,
             if ok and choice == 'y':
                 ok, choice = tui.enter_choice("Do you want to install plug-in's in GUI mode?. (u=GUI mode*, i=Interactive mode) : ",['u', 'i'], 'u')
                 if ok and choice == 'u':
-                    if not services.run_hp_tools_with_auth('hp-plugin', core.passwordObj):
-                        log.error("hp-plugin command failed. Please run hp-plugin manually.")
+                    plugin_cmd = 'hp-plugin  -u'
                 elif ok and choice == 'i':
-                    plugin_cmd = core.passwordObj.getAuthCmd() % 'hp-plugin  -i'
-                    log.info("Running '%s' command...."%plugin_cmd)
-                    if os_utils.execute(plugin_cmd) != 0:
-                        log.error("hp-plugin command failed. Please run hp-plugin manually.")
+                    plugin_cmd = 'hp-plugin  -i'
                 else:
                     log.info(log.bold("Please install hp plugin's manually, otherwise some functionality may break"))
+                if os_utils.execute(plugin_cmd) != 0:
+                    log.error("hp-plugin command failed. Please run hp-plugin manually.")
             else:
                 log.info(log.bold("Please install hp plugin's manually, otherwise some functionality may break"))
 
