@@ -501,6 +501,20 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) jd_s_channel_open(mud_
             goto bugout;
          }
          break;            
+      case HPMUD_IPP_CHANNEL:
+         port = 631;
+         pin.sin_port = htons(port);
+         if ((pc->socket = socket(AF_INET, SOCK_STREAM, 0)) == -1)
+         {
+            BUG("unable to open ipp port %d: %m %s\n", port, pd->uri);
+            goto bugout;
+         }
+         if (connect(pc->socket, (struct sockaddr *)&pin, sizeof(pin)) == -1)
+         {
+            BUG("unable to connect to ipp port %d: %m %s\n", port, pd->uri);
+            goto bugout;
+         }
+         break;
       case HPMUD_MARVELL_FAX_CHANNEL:
          port = 8285;  
          pin.sin_port = htons(port);
