@@ -35,6 +35,7 @@ import signal
 
 # Local
 from base.g import *
+#from . import base.utils as utils
 import base.utils as utils
 from base import status, tui, module
 
@@ -71,7 +72,7 @@ mod.lockInstance()
 mod.setUsage(module.USAGE_FLAG_NONE,
              extra_options=[("Disable dbus (Qt3 only):", "-x or --disable-dbus", "option", False)],
              see_also_list = ['hp-align', 'hp-clean', 'hp-colorcal', 'hp-devicesettings',
-                              'hp-hp-faxsetup', 'hp-firmware', 'hp-info', 'hp-levels',
+                              'hp-faxsetup', 'hp-firmware', 'hp-info', 'hp-levels',
                               'hp-linefeedcal', 'hp-makecopies', 'hp-plugin',
                               'hp-pqdiag', 'hp-print', 'hp-printsettings', 'hp-scan',
                               'hp-sendfax', 'hp-testpage', 'hp-timedate', 'hp-unload'])
@@ -100,8 +101,11 @@ if ui_toolkit == 'qt3':
     try:
         from dbus import SessionBus
         import dbus.service
-        from dbus.mainloop.glib import DBusGMainLoop
+        from dbus.mainloop.glib import DBusGMainLoop, threads_init
         from gobject import MainLoop
+        import glib
+        glib.threads_init()
+        dbus.mainloop.glib.threads_init()
     except ImportError:
         log.error("Unable to load dbus - Automatic status updates in HPLIP Device Manager will be disabled.")
         disable_dbus = True
@@ -184,7 +188,7 @@ if ui_toolkit == 'qt3':
                 log.debug("Killing child toolbox process (pid=%d)..." % child_pid)
                 try:
                     os.kill(child_pid, signal.SIGKILL)
-                except OSError, e:
+                except OSError as e:
                     log.debug("Failed: %s" % e.message)
 
             mod.unlockInstance()
@@ -203,7 +207,7 @@ if ui_toolkit == 'qt3':
 
             try:
                 session_bus = dbus.SessionBus()
-            except dbus.exceptions.DBusException, e:
+            except dbus.exceptions.DBusException as e:
                 if os.getuid() != 0:
                     log.error("Unable to connect to dbus session bus. Exiting.")
                     sys.exit(1)
@@ -228,7 +232,7 @@ if ui_toolkit == 'qt3':
                 log.debug("Killing parent toolbox process (pid=%d)..." % parent_pid)
                 try:
                     os.kill(parent_pid, signal.SIGKILL)
-                except OSError, e:
+                except OSError as e:
                     log.debug("Failed: %s" % e.message)
 
             mod.unlockInstance()
