@@ -22,14 +22,15 @@
 # Local
 from base.g import *
 from base import utils, magic, os_utils
+from base.sixext import  to_unicode
 from prnt import cups
-from ui_utils import load_pixmap
+from .ui_utils import load_pixmap
 
 # Qt
 from qt import *
-from scrollview import ScrollView, PixmapLabelButton
-from allowabletypesdlg import AllowableTypesDlg
-from jobstoragemixin import JobStorageMixin
+from .scrollview import ScrollView, PixmapLabelButton
+from .allowabletypesdlg import AllowableTypesDlg
+from .jobstoragemixin import JobStorageMixin
 
 # Std Lib
 import os.path
@@ -41,8 +42,8 @@ class RangeValidator(QValidator):
         QValidator.__init__(self, parent, name)
 
     def validate(self, input, pos):
-        for x in unicode(input)[pos-1:]:
-            if x not in u'0123456789,- ':
+        for x in to_unicode(input)[pos-1:]:
+            if x not in '0123456789,- ':
                 return QValidator.Invalid, pos
 
         return QValidator.Acceptable, pos
@@ -342,12 +343,12 @@ class ScrollPrintView(ScrollView):
 
         if dlg.exec_loop() == QDialog.Accepted:
                 results = dlg.selectedFile()
-                working_directory = unicode(dlg.dir().absPath())
+                working_directory = to_unicode(dlg.dir().absPath())
                 #log.debug("results: %s" % unicode(results))
                 user_conf.setWorkingDirectory(working_directory)
 
                 if results:
-                    self.addFile(unicode(results))
+                    self.addFile(to_unicode(results))
 
     def removeFile_clicked(self):
         try:
@@ -484,7 +485,7 @@ class ScrollPrintView(ScrollView):
     def pageRangeEdit_lostFocus(self):
         x = []
         try:
-            x = utils.expand_range(unicode(self.pageRangeEdit.text()))
+            x = utils.expand_range(to_unicode(self.pageRangeEdit.text()))
         except ValueError:
             log.error("Invalid page range entered.")
             self.invalid_page_range = True
@@ -970,7 +971,7 @@ class ScrollPrintView(ScrollView):
 
                 copies = int(self.copiesSpinBox.value())
                 all_pages = self.pages_button_group == 0
-                page_range = unicode(self.pageRangeEdit.text())
+                page_range = to_unicode(self.pageRangeEdit.text())
                 page_set = int(self.pageSetComboBox.currentItem())
 
                 cups.resetOptions()
